@@ -28,69 +28,61 @@ THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 #include "xf86_OSproc.h"
 
 typedef struct {
-   uint32_t YBuf0offset;
-   uint32_t UBuf0offset;
-   uint32_t VBuf0offset;
+	uint32_t YBufOffset;
+	uint32_t UBufOffset;
+	uint32_t VBufOffset;
 
-   uint32_t YBuf1offset;
-   uint32_t UBuf1offset;
-   uint32_t VBuf1offset;
+	int brightness;
+	int contrast;
+	int saturation;
+	xf86CrtcPtr desired_crtc;
 
-   unsigned char currentBuf;
+	RegionRec clip;
+	uint32_t colorKey;
 
-   int brightness;
-   int contrast;
-   int saturation;
-   xf86CrtcPtr current_crtc;
-   xf86CrtcPtr desired_crtc;
-   int doubleBuffer;
+	uint32_t gamma0;
+	uint32_t gamma1;
+	uint32_t gamma2;
+	uint32_t gamma3;
+	uint32_t gamma4;
+	uint32_t gamma5;
 
-   RegionRec clip;
-   uint32_t colorKey;
+	uint32_t videoStatus;
+	Time offTime;
+	Time freeTime;
+	/** YUV data buffers */
+	drm_intel_bo *buf;
 
-   uint32_t gamma0;
-   uint32_t gamma1;
-   uint32_t gamma2;
-   uint32_t gamma3;
-   uint32_t gamma4;
-   uint32_t gamma5;
+	Bool textured;
+	Rotation rotation;	/* should remove intel->rotation later */
 
-   uint32_t videoStatus;
-   Time offTime;
-   Time freeTime;
-   i830_memory *buf; /** YUV data buffer */
-   unsigned int extra_offset;
+	int SyncToVblank;	/* -1: auto, 0: off, 1: on */
+} intel_adaptor_private;
 
-   Bool overlayOK;
-   int oneLineMode;
-   int scaleRatio;
-   Bool textured;
-   Rotation rotation; /* should remove I830->rotation later*/
-} I830PortPrivRec, *I830PortPrivPtr;
+static inline intel_adaptor_private *
+intel_get_adaptor_private(ScrnInfoPtr scrn)
+{
+	return intel_get_screen_private(scrn)->adaptor->pPortPrivates[0].ptr;
+}
 
-#define GET_PORT_PRIVATE(pScrn) \
-   (I830PortPrivPtr)((I830PTR(pScrn))->adaptor->pPortPrivates[0].ptr)
+void I915DisplayVideoTextured(ScrnInfoPtr scrn,
+			      intel_adaptor_private *adaptor_priv,
+			      int id, RegionPtr dstRegion, short width,
+			      short height, int video_pitch, int video_pitch2,
+			      int x1, int y1, int x2, int y2,
+			      short src_w, short src_h,
+			      short drw_w, short drw_h, PixmapPtr pixmap);
 
-/*
- * Broadwater requires a bit of extra video memory for state information
- */
-#define BRW_LINEAR_EXTRA	(36*1024)
-
-void I915DisplayVideoTextured(ScrnInfoPtr pScrn, I830PortPrivPtr pPriv,
+void I965DisplayVideoTextured(ScrnInfoPtr scrn,
+			      intel_adaptor_private *adaptor_priv,
 			      int id, RegionPtr dstRegion, short width,
 			      short height, int video_pitch,
 			      int x1, int y1, int x2, int y2,
 			      short src_w, short src_h,
-			      short drw_w, short drw_h,
-			      PixmapPtr pPixmap);
-
-void I965DisplayVideoTextured(ScrnInfoPtr pScrn, I830PortPrivPtr pPriv,
-			      int id, RegionPtr dstRegion, short width,
-			      short height, int video_pitch,
-			      int x1, int y1, int x2, int y2,
-			      short src_w, short src_h,
-			      short drw_w, short drw_h,
-			      PixmapPtr pPixmap);
+			      short drw_w, short drw_h, PixmapPtr pixmap);
 
 void I830VideoBlockHandler(int i, pointer blockData, pointer pTimeout,
 			   pointer pReadmask);
+void i965_free_video(ScrnInfoPtr scrn);
+
+int is_planar_fourcc(int id);
